@@ -1,22 +1,17 @@
-from rest_framework.fields import DictField
+from rest_framework.fields import DictField, ListField
 from rest_framework.settings import api_settings
 
 from .validators import RequiredFileValidator
 
 
-class FileField(DictField):
-    """
-    A hybrid file field. Renders an input type,
-    accepts as input a dictionary containing the filename and the file path
-    and it serializes the representation like a native serializer.FileField
-    """
-
+class FileFieldMixin:
     default_validators = [RequiredFileValidator()]
+    base_template = None
 
     def __init__(self, **kwargs):
         kwargs["style"] = kwargs.get("style", {})
         if "base_template" not in kwargs["style"]:
-            kwargs["style"]["base_template"] = "file.html"
+            kwargs["style"]["base_template"] = self.base_template
         super().__init__(**kwargs)
 
     def to_representation(self, value):
@@ -35,3 +30,19 @@ class FileField(DictField):
             return url
 
         return value.name
+
+
+class FileField(FileFieldMixin, DictField):
+    """
+    A hybrid file field. Renders an input type,
+    accepts as input a dictionary containing the filename and the file path
+    and it serializes the representation like a native serializer.FileField
+    """
+    base_template = "file.html"
+
+
+class ListFileField(FileFieldMixin, ListField):
+    """
+    List of FileField
+    """
+    base_template = "file_multiple.html"
